This is a simple alternative to django-ajax-selects.

Read the documentation on http://readthedocs.org/docs/django-autocomplete-light/en/latest/

Status
------

The API is pretty stable, and it does everything we want. It has nice
documentation and design.

So, it is time for 0.1 release.
